@@ -1,4 +1,4 @@
-/* $Id: procstate.c,v 1.6 2004/10/04 12:22:15 bdejean Exp $ */
+/* $Id: procstate.c,v 1.7 2004/10/22 15:35:57 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -58,12 +58,7 @@ glibtop_get_proc_state_s (glibtop *server, glibtop_proc_state *buf,
 	memset (buf, 0, sizeof (glibtop_proc_state));
 
 	pinfo = _glibtop_get_procinfo(server, pid);
-	if (pinfo == NULL)
-	{
-		glibtop_error_io_r(server, "Cannot read procsinfo");
-
-		return;
-	}
+	if (pinfo == NULL) return;
 
 	if (pinfo->pi_pid == 0)
 	{
