@@ -1,4 +1,4 @@
-/* $Id: proclist.c,v 1.25 2004/07/18 20:33:56 bdejean Exp $ */
+/* $Id: proclist.c,v 1.25.2.1 2004/11/29 19:47:48 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -157,7 +157,7 @@ glibtop_get_proclist_s (glibtop *server, glibtop_proclist *buf,
 		if (which & GLIBTOP_EXCLUDE_IDLE) {
 			glibtop_get_proc_state_s (server, &procstate, pid);
 			if (procstate.flags & (1L << GLIBTOP_PROC_STATE_STATE))
-				if (procstate.state != 'R') continue;
+				if (procstate.state != GLIBTOP_PROCESS_RUNNING) continue;
 		}
 
 		if (which & GLIBTOP_EXCLUDE_SYSTEM) {
